# ----------------------------------------------------
# Beispiel fr Set-ACL
# ----------------------------------------------------
function Add-Security
{
  param ($Objekt,
    [Security.Principal.NTAccount]$Identity,
    [Security.AccessControl.FileSystemRights]$AccessMask,
    [Security.AccessControl.AccessControlType]$Typ)
      if ($Objekt.IsPSContainer)
      {
        $InheritanceFlags = [Security.AccessControl.InheritanceFlags]::ContainerInherit `
          -bor [Security.AccessControl.InheritanceFlags]::ObjectInherit
      }
      else
      {
        $InheritanceFlags = [Security.AccessControl.InheritanceFlags]::None
      }
      $PropagationFlags = [Security.AccessControl.PropagationFlags]::None
  # Alten ACL holen
  $ObjektACL = Get-Acl $Objekt
  # AccessRule hinzufuegen
  $SecRule = new-object Security.AccessControl.FileSystemAccessRule($Identity, `
    $AccessMask, $InheritanceFlags, $PropagationFlags, $Typ)
  $ObjektACL.AddAccessRule($SecRule)
  Set-Acl $Objekt $ObjektACL
}

# Neues Verzeichnis anlegen
$Dir = New-Item -itemtype Directory TestACL -force
$ID = new-object Security.Principal.NTAccount("Pemo")
$Rechte = [Security.AccessControl.FileSystemRights]"Read,Write"
$Typ = [Security.AccessControl.AccessControlType]::Allow
Add-Security $Dir $ID $Rechte $Typ
"Ein ACE wurde zu $Dir hinzugefuegt..."
Get-Acl $Dir

# Neue Datei anlegen
$Datei = New-Item -itemtype file TestACL.txt -force
Add-Security $Datei $ID $Rechte $Typ
"Ein ACE wurde zu $Datei hinzugefuegt..."
Get-Acl $Datei
